import cv2
from skimage import io
from pytesseract import pytesseract

def read_image_en(image):

        img_color = io.imread(image)
        img_gray = cv2.cvtColor(img_color, cv2.COLOR_BGR2GRAY)
        thresh_img = cv2.threshold(img_gray, 120, 255, cv2.THRESH_TRUNC + cv2.THRESH_OTSU)[1]
        invert_image = 255 - thresh_img
        text = pytesseract.image_to_string(invert_image, lang='eng')

        print(text)
        return text

def read_image_es(image):
        
        img_color = io.imread(image)
        img_gray = cv2.cvtColor(img_color, cv2.COLOR_BGR2GRAY)
        thresh_img = cv2.threshold(img_gray, 120, 255, cv2.THRESH_TRUNC + cv2.THRESH_OTSU)[1]
        invert_image = 255 - thresh_img
        text = pytesseract.image_to_string(invert_image, lang='spa')
        
        print(text)
        return text




import pathlib
from setuptools import find_packages, setup

HERE = pathlib.Path(__file__).parent

VERSION = '0.0.1'
PACKAGE_NAME = 'simply-ocr'
AUTHOR = 'Jeroben Guzmán'
AUTHOR_EMAIL = 'jeroguzman@gmail.com'
URL = 'https://github.com/jeroguzman'

LICENSE = 'MIT'
DESCRIPTION = 'Read text from images, using pytesseract and opencv'
LONG_DESCRIPTION = (HERE / "README.md").read_text(encoding='utf-8')
LONG_DESC_TYPE = "text/markdown"

INSTALL_REQUIRES = [
        'pytesseract',
        'opencv-python',
        'scikit-image'
      ]

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    long_description_content_type=LONG_DESC_TYPE,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    install_requires=INSTALL_REQUIRES,
    license=LICENSE,
    packages=find_packages(),
    include_package_data=True
)